@@ -1,5 +1,5 @@
 /* commands/dcc.cpp
-   Copyright (C) 2024-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2024-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -41,16 +41,17 @@
 #include <arpa/inet.h>
 #endif
 
+#include <cinttypes>
+#include <climits>
+
 #if HAVE_STD_FS
 #include <algorithm>
 #include <filesystem>
 namespace fs = std::filesystem;
 #endif
-#include <inttypes.h>
 #if WIN32
 #include <io.h>
 #endif
-#include <limits.h>
 #include <stdexcept>
 #if UNIX
 #include <unistd.h>
@@ -134,26 +135,22 @@ dcc_get::dcc_get(const char *p_nick,
 	dcc::get_file_size(p_filesize, this->size, this->unit);
 }
 
-dcc_get::dcc_get(const dcc_get &obj) : nick(obj.nick)
-    , filename(obj.filename)
-    , filesize(obj.filesize)
-    , bytes_rem(obj.bytes_rem)
-    , size(obj.size)
-    , unit(obj.unit)
-    , start(g_time_error)
-    , stop(g_time_error)
-    , fileptr(nullptr)
-    , sock(INVALID_SOCKET)
-    , ssl(nullptr)
-    , ssl_ctx(nullptr)
-    , addr(obj.addr)
-    , port(obj.port)
-    , lock(obj.lock)
+dcc_get::~dcc_get()
 {
-	debug("%s: copy constructor called", __func__);
+	debug("%s: destructor called", __func__);
+
+	try {
+		this->destroy();
+	} catch (...) {
+		/* null */;
+	}
 }
 
-dcc_get &dcc_get::operator=(const dcc_get &obj)
+/*
+ * Copy assignment operator
+ */
+dcc_get &
+dcc_get::operator=(const dcc_get &obj)
 {
 	if (&obj == this)
 		return *this;
@@ -178,17 +175,39 @@ dcc_get &dcc_get::operator=(const dcc_get &obj)
 	return *this;
 }
 
-dcc_get::~dcc_get()
+/*
+ * Copy constructor
+ */
+dcc_get::dcc_get(const dcc_get &obj) : nick(obj.nick)
+    , filename(obj.filename)
+    , filesize(obj.filesize)
+    , bytes_rem(obj.bytes_rem)
+    , size(obj.size)
+    , unit(obj.unit)
+    , start(g_time_error)
+    , stop(g_time_error)
+    , fileptr(nullptr)
+    , sock(INVALID_SOCKET)
+    , ssl(nullptr)
+    , ssl_ctx(nullptr)
+    , addr(obj.addr)
+    , port(obj.port)
+    , lock(obj.lock)
 {
-	debug("%s: destructor called", __func__);
-
-	try {
-		this->destroy();
-	} catch (...) {
-		/* null */;
-	}
+	debug("%s: copy constructor called", __func__);
 }
 
+/*
+ * Move assignment operator
+ */
+dcc_get &
+dcc_get::operator=(dcc_get &&obj) noexcept = default;
+
+/*
+ * Move constructor
+ */
+dcc_get::dcc_get(dcc_get &&obj) noexcept = default;
+
 static void
 read_and_write(SOCKET sock, SSL *ssl, FILE *fp, intmax_t &bytes_rem)
 {
@@ -572,8 +591,13 @@ public:
 	time_t	stop;
 
 	dcc_send();
-	dcc_send(const char *, const std::string);
-	~dcc_send();
+	dcc_send(const char *, const std::string &);
+	~dcc_send() noexcept;
+
+	dcc_send &operator=(const dcc_send &);
+	dcc_send(const dcc_send &);
+	dcc_send &operator=(dcc_send &&) noexcept;
+	dcc_send(dcc_send &&) noexcept;
 
 	const char	*get_filename(void);
 	intmax_t	 get_filesize(void) const;
@@ -603,7 +627,7 @@ dcc_send::dcc_send() : fileptr(nullptr)
 	BZERO(addrof(this->sb), sizeof this->sb);
 }
 
-dcc_send::dcc_send(const char *p_nick, const std::string p_full_path)
+dcc_send::dcc_send(const char *p_nick, const std::string &p_full_path)
     : fileptr(nullptr)
     , bytes_rem(0)
     , size(0.0)
@@ -631,11 +655,199 @@ dcc_send::dcc_send(const char *p_nick, const std::string p_full_path)
 	dcc::get_file_size(this->get_filesize(), this->size, this->unit);
 }
 
-dcc_send::~dcc_send()
+dcc_send::~dcc_send() noexcept
 {
 	fclose_and_null(addrof(this->fileptr));
 }
 
+/*
+ * Copy assignment operator
+ */
+dcc_send &
+dcc_send::operator=(const dcc_send &obj)
+{
+	if (&obj == this)
+		return *this;
+
+	if (!obj.nick.empty())
+		this->nick.assign(obj.nick);
+	if (!obj.full_path.empty())
+		this->full_path.assign(obj.full_path);
+
+	if (obj.fileptr) {
+		int fd[2];
+
+		if ((fd[0] = fileno(obj.fileptr)) == -1) {
+			err_log(errno, "%s: fileno", __func__);
+			this->fileptr = nullptr;
+		} else if ((fd[1] = dup(fd[0])) == -1) {
+			err_log(errno, "%s: dup", __func__);
+			this->fileptr = nullptr;
+		} else if ((this->fileptr = fdopen(fd[1], "rb")) == nullptr) {
+			err_log(errno, "%s: fdopen", __func__);
+		}
+	} else
+		this->fileptr = nullptr;
+	this->bytes_rem = obj.bytes_rem;
+
+	this->size = obj.size;
+	this->unit = obj.unit;
+
+	this->start = obj.start;
+	this->stop  = obj.stop;
+
+	memmove(this->buf, obj.buf, sizeof(this->buf));
+
+	this->lock = obj.lock;
+	this->sb   = obj.sb;
+
+	return *this;
+}
+
+/*
+ * Copy constructor
+ */
+dcc_send::dcc_send(const dcc_send &obj) : fileptr(nullptr)
+    , bytes_rem(0)
+    , size(0.0)
+    , unit('B')
+    , start(g_time_error)
+    , stop(g_time_error)
+    , lock(0)
+{
+	if (!obj.nick.empty())
+		this->nick.assign(obj.nick);
+	if (!obj.full_path.empty())
+		this->full_path.assign(obj.full_path);
+
+	if (obj.fileptr) {
+		int fd[2];
+
+		if ((fd[0] = fileno(obj.fileptr)) == -1) {
+			err_log(errno, "%s: fileno", __func__);
+			this->fileptr = nullptr;
+		} else if ((fd[1] = dup(fd[0])) == -1) {
+			err_log(errno, "%s: dup", __func__);
+			this->fileptr = nullptr;
+		} else if ((this->fileptr = fdopen(fd[1], "rb")) == nullptr) {
+			err_log(errno, "%s: fdopen", __func__);
+		}
+	} else
+		this->fileptr = nullptr;
+	this->bytes_rem = obj.bytes_rem;
+
+	this->size = obj.size;
+	this->unit = obj.unit;
+
+	this->start = obj.start;
+	this->stop  = obj.stop;
+
+	memmove(this->buf, obj.buf, sizeof(this->buf));
+
+	this->lock = obj.lock;
+	this->sb   = obj.sb;
+}
+
+/*
+ * Move assignment operator
+ */
+dcc_send &
+dcc_send::operator=(dcc_send &&obj) noexcept
+{
+	if (&obj == this)
+		return *this;
+
+	try {
+		if (!obj.nick.empty())
+			this->nick.assign(obj.nick);
+		if (!obj.full_path.empty())
+			this->full_path.assign(obj.full_path);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
+
+	this->fileptr	= obj.fileptr;
+	this->bytes_rem = obj.bytes_rem;
+
+	this->size = obj.size;
+	this->unit = obj.unit;
+
+	this->start = obj.start;
+	this->stop  = obj.stop;
+
+	memmove(this->buf, obj.buf, sizeof(this->buf));
+
+	this->lock = obj.lock;
+	this->sb   = obj.sb;
+
+	/* ------------------------------------------------------------ */
+
+	try {
+		if (!obj.nick.empty())
+			obj.nick.clear();
+		if (!obj.full_path.empty())
+			obj.full_path.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
+
+	obj.fileptr   = nullptr;
+	obj.bytes_rem = 0;
+
+	obj.size = 0.0;
+	obj.unit = 'B';
+
+	obj.start = g_time_error;
+	obj.stop  = g_time_error;
+
+	return *this;
+}
+
+/*
+ * Move constructor
+ */
+dcc_send::dcc_send(dcc_send &&obj) noexcept
+    : fileptr(obj.fileptr)
+    , bytes_rem(obj.bytes_rem)
+    , size(obj.size)
+    , unit(obj.unit)
+    , start(obj.start)
+    , stop(obj.stop)
+    , lock(obj.lock)
+    , sb(obj.sb)
+{
+	try {
+		if (!obj.nick.empty())
+			this->nick.assign(obj.nick);
+		if (!obj.full_path.empty())
+			this->full_path.assign(obj.full_path);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
+
+	memmove(this->buf, obj.buf, sizeof(this->buf));
+
+	/* ------------------------------------------------------------ */
+
+	try {
+		if (!obj.nick.empty())
+			obj.nick.clear();
+		if (!obj.full_path.empty())
+			obj.full_path.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
+
+	obj.fileptr   = nullptr;
+	obj.bytes_rem = 0;
+
+	obj.size = 0.0;
+	obj.unit = 'B';
+
+	obj.start = g_time_error;
+	obj.stop  = g_time_error;
+}
+
 const char *
 dcc_send::get_filename(void)
 {
@@ -864,7 +1076,7 @@ subcmd_ok(const char *subcmd)
 static void
 clear_completed_get_jobs(void)
 {
-	std::vector<dcc_get>::iterator it = get_db.begin();
+	auto it = get_db.begin();
 
 	while (it != get_db.end()) {
 		if (it->has_completed())
@@ -877,7 +1089,7 @@ clear_completed_get_jobs(void)
 static void
 clear_completed_send_jobs(void)
 {
-	std::vector<dcc_send>::iterator it = send_db.begin();
+	auto it = send_db.begin();
 
 	while (it != send_db.end()) {
 		if (it->has_completed())
@@ -1367,14 +1579,12 @@ subcmd_send(const char *nick, const char *file)
 		nick_lc = strToLower(sw_strdup(nick));
 		dup_check_send(nick_lc, file);
 
-#if defined(__cplusplus) && __cplusplus >= 201103L
-		dcc_send send_obj(nick_lc, std::move(full_path));
-#else
 		dcc_send send_obj(nick_lc, full_path);
-#endif
+
 		if (send_obj.get_filesize() > DCC_FILE_MAX_SIZE)
 			throw std::runtime_error("too large file");
-		send_db.push_back(send_obj);
+		else
+			send_db.push_back(send_obj);
 
 		ret = net_send("PRIVMSG %s :%cSW_DCC SEND " "%" PRIu32 " %ld "
 		    "%" PRIdMAX " %s%c",
