@@ -1,5 +1,5 @@
 /* The FTP command
-   Copyright (C) 2024-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2024-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -34,10 +34,10 @@
 #endif
 #include <sys/stat.h>
 
+#include <climits>
 #ifdef WIN32
 #include <io.h>
 #endif
-#include <limits.h>
 #include <stdexcept>
 
 #include "../assertAPI.h"
@@ -134,7 +134,8 @@ ftp_ctl_conn::~ftp_ctl_conn()
 /*
  * Copy assignment operator
  */
-ftp_ctl_conn &ftp_ctl_conn::operator=(const ftp_ctl_conn &obj)
+ftp_ctl_conn &
+ftp_ctl_conn::operator=(const ftp_ctl_conn &obj)
 {
 	if (&obj == this)
 		return *this;
@@ -180,7 +181,8 @@ ftp_ctl_conn::ftp_ctl_conn(const ftp_ctl_conn &obj)
 /*
  * Move assignment operator
  */
-ftp_ctl_conn &ftp_ctl_conn::operator=(ftp_ctl_conn &&obj)
+ftp_ctl_conn &
+ftp_ctl_conn::operator=(ftp_ctl_conn &&obj) noexcept
 {
 	if (&obj == this)
 		return *this;
@@ -188,12 +190,16 @@ ftp_ctl_conn &ftp_ctl_conn::operator=(ftp_ctl_conn &&obj)
 	if (this->res)
 		freeaddrinfo(this->res);
 
-	if (!obj.reply_vec.empty()) {
-		this->reply_vec.assign(obj.reply_vec.begin(),
-				       obj.reply_vec.end());
+	try {
+		if (!obj.reply_vec.empty()) {
+			this->reply_vec.assign(obj.reply_vec.begin(),
+					       obj.reply_vec.end());
+		}
+		if (!obj.message_concat.empty())
+			this->message_concat.assign(obj.message_concat);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
 	}
-	if (!obj.message_concat.empty())
-		this->message_concat.assign(obj.message_concat);
 
 	this->sock  = obj.sock;
 	this->state = obj.state;
@@ -203,8 +209,12 @@ ftp_ctl_conn &ftp_ctl_conn::operator=(ftp_ctl_conn &&obj)
 
 	/* ------------------------------------------------------------ */
 
-	obj.reply_vec.clear();
-	obj.message_concat.clear();
+	try {
+		obj.reply_vec.clear();
+		obj.message_concat.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	obj.sock  = INVALID_SOCKET;
 	obj.state = CONCAT_BUFFER_IS_EMPTY;
@@ -218,24 +228,32 @@ ftp_ctl_conn &ftp_ctl_conn::operator=(ftp_ctl_conn &&obj)
 /*
  * Move constructor
  */
-ftp_ctl_conn::ftp_ctl_conn(ftp_ctl_conn &&obj)
+ftp_ctl_conn::ftp_ctl_conn(ftp_ctl_conn &&obj) noexcept
     : sock(obj.sock)
     , state(obj.state)
     , res(obj.res)
 {
-	if (!obj.reply_vec.empty()) {
-		this->reply_vec.assign(obj.reply_vec.begin(),
-				       obj.reply_vec.end());
+	try {
+		if (!obj.reply_vec.empty()) {
+			this->reply_vec.assign(obj.reply_vec.begin(),
+					       obj.reply_vec.end());
+		}
+		if (!obj.message_concat.empty())
+			this->message_concat.assign(obj.message_concat);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
 	}
-	if (!obj.message_concat.empty())
-		this->message_concat.assign(obj.message_concat);
 
 	memmove(this->buf, obj.buf, sizeof(this->buf));
 
 	/* ------------------------------------------------------------ */
 
-	obj.reply_vec.clear();
-	obj.message_concat.clear();
+	try {
+		obj.reply_vec.clear();
+		obj.message_concat.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	obj.sock  = INVALID_SOCKET;
 	obj.state = CONCAT_BUFFER_IS_EMPTY;
@@ -406,7 +424,7 @@ handle_length_four(char (&numstr)[5], CSTRING token, const size_t len,
 		err_log(errno, "%s: sscanf_s() error", __func__);
 	}
 #else
-	else if (sscanf(numstr, "%d%c", &num, &ch) != 2 ||
+	else if (sscanf(numstr, "%d%c", &num, &ch) != 2 || // NOLINT
 		 ch != '-') {
 		err_log(0, "%s: sscanf() error", __func__);
 	}
@@ -499,7 +517,7 @@ numrep_t
 ftp_ctl_conn::read_reply(const int timeo)
 {
 	CSTRING				token;
-	STRING				tokstate = const_cast<STRING>("");
+	auto				tokstate = const_cast<STRING>("");
 	int				loop_run = 0;
 	static chararray_t		sep = "\r\n";
 	std::string			last_token("");
@@ -609,7 +627,8 @@ ftp_data_conn::~ftp_data_conn()
 	free(this->path);
 
 	if (this->fileptr != nullptr) {
-		fclose(this->fileptr);
+		if (fclose(this->fileptr) != 0)
+			err_log(errno, "%s: fclose error", __func__);
 		this->fileptr = nullptr;
 	}
 
@@ -625,7 +644,8 @@ ftp_data_conn::~ftp_data_conn()
 /*
  * Copy assignment operator
  */
-ftp_data_conn &ftp_data_conn::operator=(const ftp_data_conn &obj)
+ftp_data_conn &
+ftp_data_conn::operator=(const ftp_data_conn &obj)
 {
 	if (&obj == this)
 		return *this;
@@ -710,7 +730,8 @@ ftp_data_conn::ftp_data_conn(const ftp_data_conn &obj)
 /*
  * Move assignment operator
  */
-ftp_data_conn &ftp_data_conn::operator=(ftp_data_conn &&obj)
+ftp_data_conn &
+ftp_data_conn::operator=(ftp_data_conn &&obj) noexcept
 {
 	if (&obj == this)
 		return *this;
@@ -719,16 +740,20 @@ ftp_data_conn &ftp_data_conn::operator=(ftp_data_conn &&obj)
 	free(this->path);
 
 	if (this->fileptr)
-		fclose(this->fileptr);
+		(void) fclose(this->fileptr);
 	if (this->sock != INVALID_SOCKET)
 		ftp_closesocket(this->sock);
 	if (this->res)
 		freeaddrinfo(this->res);
 
-	if (!obj.vec.empty())
-		this->vec.assign(obj.vec.begin(), obj.vec.end());
-	if (!obj.message_concat.empty())
-		this->message_concat.assign(obj.message_concat);
+	try {
+		if (!obj.vec.empty())
+			this->vec.assign(obj.vec.begin(), obj.vec.end());
+		if (!obj.message_concat.empty())
+			this->message_concat.assign(obj.message_concat);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	this->full_path = obj.full_path;
 	this->path	= obj.path;
@@ -749,8 +774,12 @@ ftp_data_conn &ftp_data_conn::operator=(ftp_data_conn &&obj)
 
 	/* ------------------------------------------------------------ */
 
-	obj.vec.clear();
-	obj.message_concat.clear();
+	try {
+		obj.vec.clear();
+		obj.message_concat.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	obj.full_path = nullptr;
 	obj.path      = nullptr;
@@ -775,7 +804,7 @@ ftp_data_conn &ftp_data_conn::operator=(ftp_data_conn &&obj)
 /*
  * Move constructor
  */
-ftp_data_conn::ftp_data_conn(ftp_data_conn &&obj)
+ftp_data_conn::ftp_data_conn(ftp_data_conn &&obj) noexcept
     : full_path(obj.full_path)
     , path(obj.path)
     , filesz(obj.filesz)
@@ -787,10 +816,14 @@ ftp_data_conn::ftp_data_conn(ftp_data_conn &&obj)
     , res(obj.res)
     , port(obj.port)
 {
-	if (!obj.vec.empty())
-		this->vec.assign(obj.vec.begin(), obj.vec.end());
-	if (!obj.message_concat.empty())
-		this->message_concat.assign(obj.message_concat);
+	try {
+		if (!obj.vec.empty())
+			this->vec.assign(obj.vec.begin(), obj.vec.end());
+		if (!obj.message_concat.empty())
+			this->message_concat.assign(obj.message_concat);
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	memmove(this->buf, obj.buf, sizeof(this->buf));
 
@@ -799,8 +832,12 @@ ftp_data_conn::ftp_data_conn(ftp_data_conn &&obj)
 
 	/* ------------------------------------------------------------ */
 
-	obj.vec.clear();
-	obj.message_concat.clear();
+	try {
+		obj.vec.clear();
+		obj.message_concat.clear();
+	} catch (...) {
+		err_quit("%s: unexpected exception thrown", __func__);
+	}
 
 	obj.full_path = nullptr;
 	obj.path      = nullptr;
@@ -863,7 +900,7 @@ get_bytes(const std::string &str)
 {
 	CSTRING			bytes_str;
 	STRING			str_copy = sw_strdup(str.c_str());
-	STRING			tokstate = const_cast<STRING>("");
+	auto			tokstate = const_cast<STRING>("");
 	static chararray_t	sep	 = " \r\n";
 
 	(void) strtok_r(str_copy, sep, &tokstate);
@@ -1002,7 +1039,7 @@ numstr_t
 ftp_data_conn::list_fetch(const int timeo)
 {
 	CSTRING				token;
-	STRING				tokstate = const_cast<STRING>("");
+	auto				tokstate = const_cast<STRING>("");
 	int				loop_run = 0;
 	static chararray_t		sep = "\r\n";
 	std::string			last_token("");
@@ -1041,7 +1078,11 @@ ftp_data_conn::list_fetch(const int timeo)
 			token = this->message_concat.c_str();
 		}
 
+#if defined(__cplusplus) && __cplusplus >= 201103L
+		this->vec.emplace_back(token);
+#else
 		this->vec.push_back(token);
+#endif
 		loop_run++;
 	} /* for */
 
@@ -1430,7 +1471,7 @@ cmd_ftp(CSTRING data)
 	CSTRING			arg[2];
 	CSTRING			subcmd;
 	STRING			dcopy;
-	STRING			last = const_cast<STRING>("");
+	auto			last = const_cast<STRING>("");
 	static chararray_t	cmd = "/ftp";
 	static chararray_t	sep = "\n";
 	static const size_t	MAXARG = 300;
@@ -1672,7 +1713,7 @@ ftp::send_file(void)
 }
 
 int
-ftp::send_printf(SOCKET sock, CSTRING fmt, ...)
+ftp::send_printf(SOCKET sock, CSTRING fmt, ...) // NOLINT
 {
 	char	*buffer;
 	int	 n_sent;
