@@ -1,5 +1,5 @@
 /* commands/squery.cpp
-   Copyright (C) 2020-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2020-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -34,7 +34,6 @@
 #include <string>
 #include <vector>
 
-#include "../errHand.h"
 #include "../main.h"
 #include "../network.h"
 #include "../printtext.h"
@@ -89,7 +88,7 @@ static stringarray_t squery_commands = {
 void
 cmd_squery(CSTRING data)
 {
-	STRING			 dcopy;
+	STRING			 dcopy = nullptr;
 	static const char	 cmd[] = "/squery";
 
 	if (strings_match(data, "")) {
@@ -97,17 +96,23 @@ cmd_squery(CSTRING data)
 		return;
 	}
 
-	dcopy = sw_strdup(data);
-	(void) strFeed(dcopy, 1);
-	std::istringstream input(dcopy);
-	free(dcopy);
-
 	try {
 		std::string			token;
 		std::vector<std::string>	tokens;
 
-		while (std::getline(input, token))
+		dcopy = sw_strdup(data);
+		(void) strFeed(dcopy, 1);
+		std::istringstream input(dcopy);
+		free(dcopy);
+		dcopy = nullptr;
+
+		while (std::getline(input, token)) {
+#if defined(__cplusplus) && __cplusplus >= 201103L
+			tokens.emplace_back(token);
+#else
 			tokens.push_back(token);
+#endif
+		}
 
 		if (tokens.size() != 2)
 			throw std::runtime_error("missing arguments");
@@ -122,6 +127,8 @@ cmd_squery(CSTRING data)
 	} catch (...) {
 		printtext_print("err", "%s: %s", cmd, "unknown exception");
 	}
+
+	free(dcopy);
 }
 
 PTEXTBUF
@@ -139,7 +146,7 @@ get_list_of_matching_squery_commands(CSTRING search_var)
 
 	if (textBuf_size(matches) == 0) {
 		textBuf_destroy(matches);
-		return NULL;
+		return nullptr;
 	}
 
 	return matches;
