@@ -1,5 +1,5 @@
 /* commands/znc.cpp
-   Copyright (C) 2020-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2020-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -34,7 +34,6 @@
 #include <string>
 #include <vector>
 
-#include "../errHand.h"
 #include "../main.h"
 #include "../network.h"
 #include "../printtext.h"
@@ -187,8 +186,7 @@ send_cmd(CSTRING p_module, CSTRING p_command)
 void
 cmd_znc(CSTRING data)
 {
-	STRING			 dcopy;
-	bool			 written_linefeed = false;
+	STRING			 dcopy = nullptr;
 	static chararray_t	 cmd = "/znc";
 
 	if (strings_match(data, "")) {
@@ -196,17 +194,24 @@ cmd_znc(CSTRING data)
 		return;
 	}
 
-	if (*(dcopy = sw_strdup(data)) == '*')
-		written_linefeed = (strFeed(dcopy, 1) == 1);
-	std::istringstream input(dcopy);
-	free(dcopy);
-
 	try {
+		bool				 written_linefeed = false;
 		std::string			 token;
 		std::vector<std::string>	 tokens;
 
-		while (std::getline(input, token))
+		if (*(dcopy = sw_strdup(data)) == '*')
+			written_linefeed = (strFeed(dcopy, 1) == 1);
+		std::istringstream input(dcopy);
+		free(dcopy);
+		dcopy = nullptr;
+
+		while (std::getline(input, token)) {
+#if defined(__cplusplus) && __cplusplus >= 201103L
+			tokens.emplace_back(token);
+#else
 			tokens.push_back(token);
+#endif
+		}
 
 		if (!written_linefeed) {
 			if (tokens.size() != 1) {
@@ -227,6 +232,8 @@ cmd_znc(CSTRING data)
 	} catch (...) {
 		printtext_print("err", "%s: %s", cmd, "unknown exception");
 	}
+
+	free(dcopy);
 }
 
 PTEXTBUF
@@ -244,7 +251,7 @@ get_list_of_matching_znc_commands(CSTRING search_var)
 
 	if (textBuf_size(matches) == 0) {
 		textBuf_destroy(matches);
-		return NULL;
+		return nullptr;
 	}
 
 	return matches;
