@@ -1,5 +1,5 @@
 /* batch.cpp
-   Copyright (C) 2024, 2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2024-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -29,8 +29,8 @@
 
 #include "common.h"
 
+#include <cstdint>
 #include <stdexcept>
-#include <stdint.h>
 #include <string>
 #include <vector>
 
@@ -52,16 +52,14 @@ public:
 	std::vector<std::string>	params;
 	std::vector<std::string>	irc_msgs;
 
-	batch()
+	batch() : type(BATCH_UNKNOWN)
 	{
 		this->ref.assign("");
-		this->type = BATCH_UNKNOWN;
 	}
 
-	batch(CSTRING p_ref, const batch_t p_type)
+	batch(CSTRING p_ref, const batch_t p_type) : type(p_type)
 	{
 		this->ref.assign(p_ref);
-		this->type = p_type;
 	}
 
 	CSTRING
@@ -124,10 +122,10 @@ get_obj_by_ref(CSTRING ref, batch &obj, std::vector<batch>::size_type &pos)
 static void
 create_batch(STRING params)
 {
-	CSTRING     ref, type_str;
-	CSTRING     token;
-	STRING      last = const_cast<STRING>("");
-	batch_t     type;
+	CSTRING ref, type_str;
+	CSTRING token;
+	auto	last = const_cast<STRING>("");
+	batch_t type;
 
 	if ((ref = strtok_r(params, " ", &last)) == nullptr)
 		throw std::runtime_error("null ref");
@@ -146,8 +144,13 @@ create_batch(STRING params)
 
 	batch batch_obj(ref, type);
 
-	while ((token = strtok_r(nullptr, " ", &last)) != nullptr)
+	while ((token = strtok_r(nullptr, " ", &last)) != nullptr) {
+#if defined(__cplusplus) && __cplusplus >= 201103L
+		batch_obj.params.emplace_back(token);
+#else
 		batch_obj.params.push_back(token);
+#endif
+	}
 
 #if defined(__cplusplus) && __cplusplus >= 201103L
 	batch_db.emplace_back(batch_obj);
@@ -347,7 +350,12 @@ event_batch_add_irc_msgs(CSTRING ref, CSTRING msg)
 		if (!get_obj_by_ref(ref, dummy, pos))
 			throw std::runtime_error("cannot find batch");
 
+#if defined(__cplusplus) && __cplusplus >= 201103L
+		batch_db.at(pos).irc_msgs.emplace_back(msg);
+#else
 		batch_db.at(pos).irc_msgs.push_back(msg);
+#endif
+
 	} catch (const std::bad_alloc &e) {
 		err_exit(ENOMEM, "%s: error: %s", __func__, e.what());
 	} catch (const std::out_of_range &e) {
