@@ -1,5 +1,5 @@
 /* Channel related events
-   Copyright (C) 2015-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2015-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -29,8 +29,8 @@
 
 #include "common.h"
 
+#include <ctime>
 #include <stdexcept>
-#include <time.h>
 
 #include "../config.h"
 #include "../dataClassify.h"
@@ -75,8 +75,8 @@ event_chan_hp(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*channel, *homepage;
-		char	*state = const_cast<char *>("");
+		CSTRING channel, homepage;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
@@ -433,14 +433,14 @@ chg_status_for_voice(plus_minus_state_t pm_state, const char *nick,
 static void
 maintain_channel_stats(const char *channel, const char *input)
 {
-	char			*input_copy;
-	char			*nicks[15] = { nullptr };
-	char			*state = const_cast<char *>("");
-	const char		*modes = nullptr;
-	plus_minus_state_t	 pm_state = STATE_NEITHER_PM;
-	size_t			 ar_i = 0;
-	size_t			 nicks_assigned = 0;
-	static const size_t	 ar_sz = ARRAY_SIZE(nicks);
+	CSTRING			modes	       = nullptr;
+	STRING			input_copy;
+	STRING			nicks[15]      = { nullptr };
+	auto			state	       = const_cast<STRING>("");
+	plus_minus_state_t	pm_state       = STATE_NEITHER_PM;
+	size_t			ar_i	       = 0;
+	size_t			nicks_assigned = 0;
+	static const size_t	ar_sz	       = ARRAY_SIZE(nicks);
 
 	input_copy = sw_strdup(input);
 
@@ -669,8 +669,8 @@ event_nick(struct irc_message_compo *compo)
 	try {
 		CSTRING new_nick;
 		CSTRING nick, user, host;
-		STRING prefix = nullptr;
-		STRING state = const_cast<STRING>("");
+		STRING	prefix = nullptr;
+		auto	state  = const_cast<STRING>("");
 
 		if (compo->prefix == nullptr)
 			throw std::runtime_error("no prefix");
@@ -806,7 +806,9 @@ is_valid_server(const char *str)
 {
 	int			dots = 0;
 	static const char	serv_chars[] =
-	    "abcdefghijklmnopqrstuvwxyz.0123456789-ABCDEFGHIJKLMNOPQRSTUVWXYZ*";
+				  "abcdefghijklmnopqrstuvwxyz."
+				  "0123456789-"
+				  "ABCDEFGHIJKLMNOPQRSTUVWXYZ*";
 	static const size_t	maxlen = 255;
 
 	if (str == nullptr || strings_match(str, "") ||
@@ -842,9 +844,9 @@ is_valid_server(const char *str)
 static bool
 is_netsplit(CSTRING msg, std::string &serv1, std::string &serv2)
 {
-	CSTRING     token[2];
-	STRING      last = const_cast<STRING>("");
-	STRING      msg_copy = nullptr;
+	CSTRING token[2];
+	STRING	msg_copy = nullptr;
+	auto	last	 = const_cast<STRING>("");
 
 	if (g_icb_mode ||
 	    strncmp(msg, "Quit: ", 6) == STRINGS_MATCH) {
@@ -933,7 +935,7 @@ event_quit(struct irc_message_compo *compo)
 		CSTRING message;
 		CSTRING nick, user, host;
 		STRING	prefix;
-		STRING	state = const_cast<STRING>("");
+		auto	state = const_cast<STRING>("");
 
 		if (compo->prefix == nullptr)
 			throw std::runtime_error("no prefix");
@@ -986,8 +988,8 @@ event_topic(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char	*channel, *topic;
-		char	*state = const_cast<char *>("");
+		CSTRING channel, topic;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
@@ -1124,7 +1126,7 @@ event_topic_creator(struct irc_message_compo *compo)
 		else if (!is_numeric(time_str))
 			throw std::runtime_error("expected numeric string");
 
-		const time_t timestamp = static_cast<time_t>(strtol(time_str,
+		const auto timestamp = static_cast<time_t>(strtol(time_str,
 		    nullptr, 10));
 
 #if defined(UNIX)
