@@ -1,5 +1,5 @@
 /* Whois events
-   Copyright (C) 2014-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2014-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -48,13 +48,6 @@
 #define NO_MSG "no message"
 
 class time_idle {
-	long int	days;
-	long int	hours;
-	long int	mins;
-	long int	secs;
-
-	char buf[200];
-
 public:
 	time_idle(long int, long int);
 
@@ -82,20 +75,32 @@ public:
 		return this->secs;
 	}
 
-	const char *
+	CSTRING
 	getBuf(void) const
 	{
 		return (&this->buf[0]);
 	}
+
+private:
+	long int	days;
+	long int	hours;
+	long int	mins;
+	long int	secs;
+
+	char buf[200];
 };
 
 time_idle::time_idle(long int sec_idle, long int signon_time)
+    : days(0)
+    , hours(0)
+    , mins(0)
+    , secs(0)
 {
-	struct tm	res = { 0 };
-	time_t		elapsed = signon_time;
+	const time_t	elapsed = signon_time;
+	struct tm	res	= { 0 };
 
 #if defined(UNIX)
-	if (localtime_r(&elapsed, &res) == NULL)
+	if (localtime_r(&elapsed, &res) == nullptr)
 		throw std::runtime_error("cannot retrieve tm structure");
 #elif defined(WIN32)
 	if (localtime_s(&res, &elapsed) != 0)
@@ -112,10 +117,10 @@ time_idle::time_idle(long int sec_idle, long int signon_time)
 }
 
 static bool
-get_msg(char *params, std::string &str)
+get_msg(STRING params, std::string &str)
 {
-	char *msg;
-	char *state = const_cast<char *>("");
+	CSTRING msg;
+	auto	state = const_cast<STRING>("");
 
 	if (strFeed(params, 2) != 2) {
 		(void) str.assign("");
@@ -123,9 +128,9 @@ get_msg(char *params, std::string &str)
 	}
 
 	(void) strtok_r(params, "\n", &state);
-	(void) strtok_r(NULL, "\n", &state);
+	(void) strtok_r(nullptr, "\n", &state);
 
-	if ((msg = strtok_r(NULL, "\n", &state)) == NULL) {
+	if ((msg = strtok_r(nullptr, "\n", &state)) == nullptr) {
 		(void) str.assign("");
 		return false;
 	}
@@ -159,48 +164,46 @@ event_whoReply(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_status_window, TYPE_SPEC1, true);
 
 	try {
-		char	*channel, *user, *host, *server, *nick, *symbol,
-			*hopcount, *rl_name;
-		char	*state = const_cast<char *>("");
+		CSTRING channel, user, host, server, nick, symbol, hopcount,
+			rl_name;
+		auto state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 8) != 8)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state); /* my nick */
 
-		if ((channel = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (user = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (host = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (server = strtok_r(NULL, "\n", &state)) == NULL || // unused
-		    (nick = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (symbol = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (hopcount = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (rl_name = strtok_r(NULL, "\n", &state)) == NULL) {
+		if ((channel  = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (user     = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (host     = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (server   = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (nick     = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (symbol   = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (hopcount = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (rl_name  = strtok_r(nullptr, "\n", &state)) == nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
 
-		(void) server;
+		UNUSED_VAR(server);
 
 		if (*hopcount == ':')
 			hopcount++;
 
-		std::string	str1("");
-		std::string	str2("");
-		std::string	str3("");
+		std::string s[3];
 
-		str1.append(LEFT_BRKT);
-		str1.append(COLOR1).append(channel).append(TXT_NORMAL);
-		str1.append(RIGHT_BRKT);
+		s[0].assign(LEFT_BRKT);
+		s[0].append(COLOR1).append(channel).append(TXT_NORMAL);
+		s[0].append(RIGHT_BRKT);
 
-		str2.append(COLOR2).append(nick).append(TXT_NORMAL);
+		s[1].assign(COLOR2).append(nick).append(TXT_NORMAL);
 
-		str3.append(LEFT_BRKT);
-		str3.append(COLOR2).append(rl_name).append(TXT_NORMAL);
-		str3.append(RIGHT_BRKT);
+		s[2].assign(LEFT_BRKT);
+		s[2].append(COLOR2).append(rl_name).append(TXT_NORMAL);
+		s[2].append(RIGHT_BRKT);
 
-		printtext(&ctx, "%s: %s %s %s %s@%s %s", str1.c_str(),
-		    str2.c_str(), symbol, hopcount, user, host, str3.c_str());
+		printtext(&ctx, "%s: %s %s %s %s@%s %s", s[0].c_str(),
+		    s[1].c_str(), symbol, hopcount, user, host, s[2].c_str());
 	} catch (const std::bad_alloc &e) {
 		err_exit(ENOMEM, "%s(%s): error: %s", __func__, compo->command,
 		    e.what());
@@ -227,18 +230,19 @@ event_whois_acc(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*account_name;
-		char	*comment;
-		char	*state = const_cast<char *>("");
+		CSTRING account_name;
+		CSTRING comment;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 3) != 3)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((account_name = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (comment = strtok_r(NULL, "\n", &state)) == NULL) {
+		if ((account_name = strtok_r(nullptr, "\n", &state)) ==
+		    nullptr ||
+		    (comment = strtok_r(nullptr, "\n", &state)) == nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
@@ -252,8 +256,8 @@ event_whois_acc(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_acc(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -269,16 +273,16 @@ event_whois_away(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*away_reason;
-		char	*state = const_cast<char *>("");
+		CSTRING away_reason;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((away_reason = strtok_r(NULL, "\n", &state)) == NULL)
+		if ((away_reason = strtok_r(nullptr, "\n", &state)) == nullptr)
 			throw std::runtime_error("no away reason");
 		if (*away_reason == ':')
 			away_reason++;
@@ -291,8 +295,8 @@ event_whois_away(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_away(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -320,8 +324,8 @@ event_whois_bot(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_bot(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -338,17 +342,17 @@ event_whois_cert(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*msg;
-		char	*state = const_cast<char *>("");
-		char	*tnick;
+		CSTRING msg;
+		CSTRING tnick;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
 
-		if ((tnick = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (msg = strtok_r(NULL, "\n", &state)) == NULL) {
+		if ((tnick = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (msg = strtok_r(nullptr, "\n", &state)) == nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
@@ -362,8 +366,8 @@ event_whois_cert(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_cert(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -379,16 +383,16 @@ event_whois_channels(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*chan_list;
-		char	*state = const_cast<char *>("");
+		CSTRING chan_list;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((chan_list = strtok_r(NULL, "\n", &state)) == NULL)
+		if ((chan_list = strtok_r(nullptr, "\n", &state)) == nullptr)
 			throw std::runtime_error("no chan list");
 		if (*chan_list == ':')
 			chan_list++;
@@ -400,8 +404,8 @@ event_whois_channels(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_channels(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -430,8 +434,8 @@ event_whois_conn(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_conn(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -449,24 +453,25 @@ event_whois_host(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*state = const_cast<char *>("");
-		char	*str;
+		STRING	 str;
+		auto	 state = const_cast<STRING>("");
 		char	*str_copy, *cp;
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((str = strtok_r(NULL, "\n", &state)) == NULL)
+		if ((str = strtok_r(nullptr, "\n", &state)) == nullptr)
 			throw std::runtime_error("null string");
 		else if (*str == ':')
 			str++;
 
 		str_copy = sw_strdup(str);
 
-		if ((cp = strstr(str_copy, ":actually using host")) != NULL &&
+		if ((cp = strstr(str_copy, ":actually using host")) !=
+		    nullptr &&
 		    strlen(cp) == 20) {
 			cp++;
 			memmove(cp - 1, cp, strlen(cp) + 1);
@@ -478,8 +483,8 @@ event_whois_host(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_host(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -496,22 +501,24 @@ event_whois_idle(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char		*ep1 = const_cast<char *>("");
-		char		*ep2 = const_cast<char *>("");
-		char		*state = const_cast<char *>("");
-		const char	*sec_idle_str = NULL;
-		const char	*signon_time_str = NULL;
-		long int	 sec_idle = LONG_MAX;
-		long int	 signon_time = LONG_MAX;
+		CSTRING		sec_idle_str	= nullptr;
+		CSTRING		signon_time_str = nullptr;
+		auto		ep1		= const_cast<STRING>("");
+		auto		ep2		= const_cast<STRING>("");
+		auto		state		= const_cast<STRING>("");
+		long int	sec_idle	= LONG_MAX;
+		long int	signon_time	= LONG_MAX;
 
 		if (strFeed(compo->params, 4) != 4)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((sec_idle_str = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (signon_time_str = strtok_r(NULL, "\n", &state)) == NULL) {
+		if ((sec_idle_str = strtok_r(nullptr, "\n", &state)) ==
+		    nullptr ||
+		    (signon_time_str = strtok_r(nullptr, "\n", &state)) ==
+		    nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
@@ -545,8 +552,8 @@ event_whois_idle(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_idle(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -574,8 +581,8 @@ event_whois_ircOp(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_ircOp(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -606,8 +613,8 @@ event_whois_modes(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_modes(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -623,18 +630,18 @@ event_whois_server(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*srv, *info;
-		char	*state = const_cast<char *>("");
+		CSTRING srv, info;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 3) != 3)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
 
-		if ((srv = strtok_r(NULL, "\n", &state)) == NULL)
+		if ((srv = strtok_r(nullptr, "\n", &state)) == nullptr)
 			throw std::runtime_error("no server");
-		else if ((info = strtok_r(NULL, "\n", &state)) == NULL)
+		else if ((info = strtok_r(nullptr, "\n", &state)) == nullptr)
 			throw std::runtime_error("no info");
 
 		if (*info == ':')
@@ -647,8 +654,8 @@ event_whois_server(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_server(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -676,8 +683,8 @@ event_whois_service(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_service(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -695,16 +702,16 @@ event_whois_ssl(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*tnick, *msg;
-		char	*state = const_cast<char *>("");
+		CSTRING tnick, msg;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 2) != 2)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state);
 
-		if ((tnick = strtok_r(NULL, "\n", &state)) == NULL ||
-		    (msg = strtok_r(NULL, "\n", &state)) == NULL) {
+		if ((tnick = strtok_r(nullptr, "\n", &state)) == nullptr ||
+		    (msg = strtok_r(nullptr, "\n", &state)) == nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
@@ -719,8 +726,8 @@ event_whois_ssl(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_ssl(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
 
@@ -737,21 +744,21 @@ event_whois_user(struct irc_message_compo *compo)
 	printtext_context_init(&ctx, g_active_window, TYPE_SPEC1, true);
 
 	try {
-		char	*nick, *user, *host, *rl_name;
-		char	*state = const_cast<char *>("");
+		CSTRING nick, user, host, rl_name;
+		auto	state = const_cast<STRING>("");
 
 		if (strFeed(compo->params, 5) != 5)
 			throw std::runtime_error("strFeed");
 
 		(void) strtok_r(compo->params, "\n", &state); /* <issuer> */
-		nick = strtok_r(NULL, "\n", &state);
-		user = strtok_r(NULL, "\n", &state);
-		host = strtok_r(NULL, "\n", &state);
-		(void) strtok_r(NULL, "\n", &state);
-		rl_name = strtok_r(NULL, "\n", &state);
+		nick = strtok_r(nullptr, "\n", &state);
+		user = strtok_r(nullptr, "\n", &state);
+		host = strtok_r(nullptr, "\n", &state);
+		(void) strtok_r(nullptr, "\n", &state);
+		rl_name = strtok_r(nullptr, "\n", &state);
 
-		if (nick == NULL || user == NULL || host == NULL || rl_name ==
-		    NULL) {
+		if (nick == nullptr || user == nullptr || host == nullptr ||
+		    rl_name == nullptr) {
 			throw std::runtime_error("unable to retrieve event "
 			    "components");
 		}
@@ -769,7 +776,7 @@ event_whois_user(struct irc_message_compo *compo)
 		ctx.window	= g_status_window;
 		ctx.spec_type	= TYPE_SPEC1_WARN;
 
-		printtext(&ctx, "event_whois_user(%s): error: %s",
-		    compo->command, e.what());
+		printtext(&ctx, "%s(%s): error: %s", __func__, compo->command,
+			  e.what());
 	}
 }
