@@ -1,5 +1,5 @@
 /* get_x509_fp.cpp
-   Copyright (C) 2023-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2023-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -77,6 +77,49 @@ x509_fingerprint::~x509_fingerprint()
 		X509_free(this->cert);
 }
 
+/*
+ * Copy assignment operator
+ */
+x509_fingerprint &
+x509_fingerprint::operator=(const x509_fingerprint &obj)
+{
+	if (&obj == this)
+		return *this;
+
+	this->bio  = nullptr;
+	this->cert = nullptr;
+	this->alg  = nullptr;
+
+	memmove(this->md, obj.md, sizeof(this->md));
+
+	this->md_len = obj.md_len;
+
+	return *this;
+}
+
+/*
+ * Copy constructor
+ */
+x509_fingerprint::x509_fingerprint(const x509_fingerprint &obj)
+    : bio(nullptr)
+    , cert(nullptr)
+    , alg(nullptr)
+    , md_len(obj.md_len)
+{
+	memmove(this->md, obj.md, sizeof(this->md));
+}
+
+/*
+ * Move assignment operator
+ */
+x509_fingerprint &
+x509_fingerprint::operator=(x509_fingerprint &&obj) noexcept = default;
+
+/*
+ * Move constructor
+ */
+x509_fingerprint::x509_fingerprint(x509_fingerprint &&obj) noexcept = default;
+
 void
 x509_fingerprint::show_fp(void) const
 {
