@@ -81,6 +81,7 @@
 #include "commands/squery.h"
 #include "commands/theme.h"
 #include "commands/topic.h"
+#include "commands/userhost.h"
 #include "commands/utctime.h"
 #include "commands/voice.h"
 #include "commands/wholeft.h"
@@ -177,6 +178,7 @@ static struct cmds_tag {
 	{ "topic",       cmd_topic,       true,  topic_usage,       ARRAY_SIZE(topic_usage),       false },
 	{ "unban",       cmd_unban,       true,  unban_usage,       ARRAY_SIZE(unban_usage),       true  },
 	{ "unignore",    cmd_unignore,    false, unignore_usage,    ARRAY_SIZE(unignore_usage),    false },
+	{ "userhost",    cmd_userhost,    true,  userhost_usage,    ARRAY_SIZE(userhost_usage),    true  },
 	{ "utctime",     cmd_utctime,     false, utctime_usage,     ARRAY_SIZE(utctime_usage),     false },
 	{ "version",     cmd_version,     true,  version_usage,     ARRAY_SIZE(version_usage),     true  },
 	{ "voice",       cmd_voice,       true,  voice_usage,       ARRAY_SIZE(voice_usage),       true  },
@@ -809,12 +811,11 @@ transmit_user_input(CSTRING winlabel, CSTRING input)
 		}
 	}
 
-#define S1 Theme("nick_s1")
-#define S2 Theme("nick_s2")
+	immutable_cp_t	cp[2] = { Theme("nick_s1"), Theme("nick_s2") };
 
 	if (!is_irc_channel(winlabel)) {
 		printtext(&ctx, "%s%s%s%c%s %s",
-		    S1, COLOR1, g_my_nickname, NORMAL, S2,
+		    cp[0], COLOR1, g_my_nickname, NORMAL, cp[1],
 		    input);
 	} else {
 		PNAMES	n;
@@ -840,7 +841,7 @@ transmit_user_input(CSTRING winlabel, CSTRING input)
 			c = ' ';
 
 		printtext(&ctx, "%s%c%s%s%c%s %s",
-		    S1, c, COLOR1, g_my_nickname, NORMAL, S2,
+		    cp[0], c, COLOR1, g_my_nickname, NORMAL, cp[1],
 		    input);
 	}
 }
