@@ -1,5 +1,5 @@
 /* Handle and interpret IRC events
-   Copyright (C) 2014-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2014-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -44,7 +44,6 @@
 #include "readline.h"		/* readline_top_panel() */
 #include "statusbar.h"
 #include "strHand.h"
-#include "strdup_printf.h"
 
 #include "events/account.h"
 #include "events/auth.h"
@@ -166,6 +165,7 @@ static struct numeric_events_tag {
 	{ "275", "",                        NO_WINDOW,      0, event_whois_ssl },
 	{ "276", "",                        NO_WINDOW,      0, event_whois_cert },
 	{ "301", "RPL_AWAY",                NO_WINDOW,      0, event_whois_away },
+	{ "302", "RPL_USERHOST",            NO_WINDOW,      0, event_userhost },
 	{ "303", "RPL_ISON",                ACTIVE_WINDOW,  1, NULL },
 	{ "305", "RPL_UNAWAY",              NO_WINDOW,      0, event_unaway },
 	{ "306", "RPL_NOWAWAY",             NO_WINDOW,      0, event_nowAway },
@@ -297,10 +297,12 @@ static struct numeric_events_tag {
 ****************************************************************/
 
 //lint -sem(SortMsgCompo, r_null)
+//lint -sem(get_last_token, r_null)
 
 static struct irc_message_compo *
 		 SortMsgCompo(const char *);
 static void	 FreeMsgCompo(struct irc_message_compo *);
+static char	*get_last_token(const char *) NONNULL;
 
 static int
 cmp_fn(const void *vp1, const void *vp2)
@@ -692,13 +694,10 @@ get_last_token(const char *buffer)
 {
 	const char *last_token;
 
-	if ((last_token = strrchr(buffer, '\n')) == NULL) {
-		err_msg("%s error. (this is a bug and shouldn't happen!)",
-		    __func__);
-		abort();
-	}
+	if ((last_token = strrchr(buffer, '\n')) == NULL)
+		return NULL;
 
-	return sw_strdup(++ last_token);
+	return sw_strdup(++last_token);
 }
 
 static inline bool
@@ -732,8 +731,13 @@ irc_handle_interpret_events(char *recvbuffer, char **message_concat,
 		*state = CONCAT_BUFFER_IS_EMPTY;
 	}
 
-	if (!is_terminated_recvchunk(recvbuffer[strlen(recvbuffer) - 1]))
-		last_token = get_last_token(recvbuffer); /* Must be freed */
+	if (!is_terminated_recvchunk(recvbuffer[strlen(recvbuffer) - 1]) &&
+	    (last_token = get_last_token(recvbuffer)) == NULL) {
+		printtext_print("err", "%s: unable to get the last token: "
+		    "requesting disconnect...", __func__);
+		net_request_disconnect();
+		return;
+	}
 
 	cp = &recvbuffer[0];
 	loop_count = 0;
