@@ -42,8 +42,6 @@
 #define OPENSSL_VERSION_TEXT "Unknown"
 #endif
 
-#include <locale.h>
-
 #if UNIX
 #include <swircpaths.h>
 #include <unistd.h> /* geteuid() pledge() */
@@ -54,6 +52,7 @@
 #include <process.h> /* _getpid() */
 #endif
 
+#include <clocale>
 #include <exception>
 
 #include "assertAPI.h"
@@ -93,7 +92,7 @@
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.5.8";
+chararray_t	g_swircVersion	= "v3.5.9";
 chararray_t	g_swircYear	= "2012-2026";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
@@ -125,7 +124,21 @@ bool	g_ircv3_extensions	= true;
 bool	g_sasl_authentication	= true;
 bool	g_ssl_verify_peer	= true;
 
-struct cmdline_opt_values *g_cmdline_opts = new cmdline_opt_values();
+static struct cmdline_opt_values *
+cmdline_opts_init(void) noexcept
+{
+	try {
+		struct cmdline_opt_values *opts;
+
+		opts = new cmdline_opt_values();
+		return opts;
+	} catch (...) {
+		err_msg("%s: cannot continue", __func__);
+		abort();
+	}
+}
+
+struct cmdline_opt_values *g_cmdline_opts = cmdline_opts_init();
 
 /* Things with internal linkage
    ============================ */
@@ -324,7 +337,7 @@ static void
 case_connect()
 {
 	CSTRING		token[2];
-	STRING		last = const_cast<STRING>("");
+	auto		last = const_cast<STRING>("");
 	static bool	been_case = false;
 
 	if (been_case)
@@ -386,12 +399,18 @@ case_join()
 	for (cp = g_option_arg;; cp = nullptr) {
 		char *token;
 
-		if ((token = strtok_r(cp, ",", &last)) == nullptr)
+		if ((token = strtok_r(cp, ",", &last)) == nullptr) {
 			break;
-		else if (strpbrk(token, g_forbidden_chan_name_chars) != nullptr)
+		} else if (strpbrk(token, g_forbidden_chan_name_chars) !=
+		    nullptr) {
 			err_quit("%s", _("forbidden channel name characters"));
-		else
+		} else {
+#if defined(__cplusplus) && __cplusplus >= 201103L
+			g_join_list.emplace_back(token);
+#else
 			g_join_list.push_back(token);
+#endif
+		}
 	}
 
 	been_case = true;
@@ -836,10 +855,10 @@ main(int argc, char *argv[])
 struct locale_info *
 get_locale_info(int category)
 {
-	char			*last = const_cast<char *>("");
-	char			*tok;
-	char			 buf[200] = { '\0' };
-	struct locale_info	*li = new locale_info();
+	auto	 li = new locale_info();
+	char	 buf[200] = { '\0' };
+	char	*last = const_cast<char *>("");
+	char	*tok;
 
 	if (sw_strcpy(buf, xsetlocale(category, nullptr), ARRAY_SIZE(buf)) != 0)
 		return (li);
@@ -886,7 +905,8 @@ locale_info::locale_info(const locale_info &obj)
 /*
  * Move assignment operator
  */
-locale_info &locale_info::operator=(locale_info &&obj)
+locale_info &
+locale_info::operator=(locale_info &&obj) noexcept
 {
 	if (&obj == this)
 		return *this;
@@ -906,7 +926,7 @@ locale_info &locale_info::operator=(locale_info &&obj)
 /*
  * Move constructor
  */
-locale_info::locale_info(locale_info &&obj)
+locale_info::locale_info(locale_info &&obj) noexcept
     : lang_and_territory(obj.lang_and_territory)
     , codeset(obj.codeset)
 {
@@ -997,7 +1017,8 @@ cmdline_opt_values::cmdline_opt_values(const cmdline_opt_values &obj)
 /*
  * Move assignment operator
  */
-cmdline_opt_values &cmdline_opt_values::operator=(cmdline_opt_values &&obj)
+cmdline_opt_values &
+cmdline_opt_values::operator=(cmdline_opt_values &&obj) noexcept
 {
 	if (&obj == this)
 		return *this;
@@ -1035,7 +1056,7 @@ cmdline_opt_values &cmdline_opt_values::operator=(cmdline_opt_values &&obj)
 /*
  * Move constructor
  */
-cmdline_opt_values::cmdline_opt_values(cmdline_opt_values &&obj)
+cmdline_opt_values::cmdline_opt_values(cmdline_opt_values &&obj) noexcept
     : server(obj.server)
     , port(obj.port)
     , passwd(obj.passwd)
