@@ -92,6 +92,67 @@ struct message_components {
 		this->text = nullptr;
 	}
 
+	/*
+	 * Copy assignment operator
+	 */
+	message_components &
+	operator=(const message_components &obj)
+	{
+		if (&obj == this)
+			return (*this);
+
+		if (obj.text)
+			this->text = sw_strdup(obj.text);
+
+		this->indent = obj.indent;
+
+		return (*this);
+	}
+
+	/*
+	 * Copy constructor
+	 */
+	message_components(const message_components &obj)
+	    : text(nullptr)
+	    , indent(0)
+	{
+		if (obj.text)
+			this->text = sw_strdup(obj.text);
+
+		this->indent = obj.indent;
+	}
+
+	/*
+	 * Move assignment operator
+	 */
+	message_components &
+	operator=(message_components &&obj) noexcept
+	{
+		if (&obj == this)
+			return (*this);
+
+		free(this->text);
+
+		this->text   = obj.text;
+		this->indent = obj.indent;
+
+		obj.text   = nullptr;
+		obj.indent = 0;
+
+		return (*this);
+	}
+
+	/*
+	 * Move constructor
+	 */
+	message_components(message_components &&obj) noexcept
+	    : text(obj.text)
+	    , indent(obj.indent)
+	{
+		obj.text   = nullptr;
+		obj.indent = 0;
+	}
+
 	void get_msg(CSTRING, enum message_specifier_type, bool, CSTRING);
 };
 
@@ -258,7 +319,8 @@ static struct ptext_colorMap_tag {
 *                                                               *
 ****************************************************************/
 
-static char *get_buffer(CSTRING) NONNULL;
+static void	 set_indent(int *, CSTRING, ...) PRINTFLIKE(2);
+static char	*get_buffer(CSTRING) NONNULL;
 
 static void
 addmbs(WINDOW *win, const uint8_t *mbs)
@@ -337,9 +399,9 @@ static UCHARPTR
 convert_wc(wchar_t wc, size_t &bytes_out)
 {
 	const size_t	 size = MB_LEN_MAX;
+	auto		 mbs = static_cast<UCHARPTR>(xmalloc(size + 1));
 	mbstate_t	 ps;
 	size_t		 bytes_written = 0;
-	UCHARPTR	 mbs = static_cast<UCHARPTR>(xmalloc(size + 1));
 
 	BZERO(&ps, sizeof(mbstate_t));
 	mbs[size] = '\0';
@@ -576,10 +638,11 @@ map_color(short int *inout, const short int i, const short int colorMap_size,
 void
 printtext_set_color(WINDOW *win, bool *is_color, short int num1, short int num2)
 {
-	attr_t attr = 0xff;
-	const short int num_colorMap_entries = static_cast<short int>
-	    (COLORS >= 256 ? ARRAY_SIZE(ptext_colorMap) : 16);
-	short int fg, bg, resolved_pair;
+	attr_t		attr = 0xff;
+	const auto	num_colorMap_entries =
+			    static_cast<short int>(COLORS >= 256 ?
+			    ARRAY_SIZE(ptext_colorMap) : 16);
+	short int	fg, bg, resolved_pair;
 
 	sw_assert(num1 >= 0);
 
@@ -613,10 +676,10 @@ init_numbers(CSTRING fg, CSTRING bg, short int &num1, short int &num2)
 {
 	struct integer_context intctx("term_background", 0, 15, 1);
 
-	num1 = static_cast<short int>(atoi(fg));
+	num1 = static_cast<short int>(strtol(fg, nullptr, 10));
 
 	if (!isEmpty(bg))
-		num2 = static_cast<short int>(atoi(bg));
+		num2 = static_cast<short int>(strtol(bg, nullptr, 10));
 	else if (isEmpty(bg) && theme_bool("term_use_default_colors", true))
 		num2 = -1;
 	else
@@ -826,7 +889,7 @@ case_underline(WINDOW *win, bool *is_underline)
 }
 
 static void
-set_indent(int *indent, CSTRING fmt, ...)
+set_indent(int *indent, CSTRING fmt, ...) // NOLINT
 {
 	STRING		 str = nullptr;
 	size_t		 bytes_convert;
@@ -1194,7 +1257,7 @@ PPRINTTEXT_CONTEXT
 printtext_context_new(PIRC_WINDOW window, enum message_specifier_type spec_type,
     bool include_ts)
 {
-	PPRINTTEXT_CONTEXT ctx =
+	PPRINTTEXT_CONTEXT ctx = // NOLINT
 	    static_cast<PPRINTTEXT_CONTEXT>(xcalloc(sizeof *ctx, 1));
 
 	ctx->window     = window;
@@ -1407,8 +1470,7 @@ get_buffer(CSTRING orig)
 		iconv_t		 cd;
 		size_t		 inbytes, outbytes, outsize;
 
-		if ((cd = iconv_open("UTF-8", str)) == reinterpret_cast
-		    <iconv_t>(-1))
+		if ((cd = iconv_open("UTF-8", str)) == g_iconv_error)
 			continue;
 		orig_copy = sw_strdup(orig);
 		in = addrof(orig_copy[0]);
@@ -1539,8 +1601,8 @@ printtext_puts(WINDOW *pwin, CSTRING buf, int indent, int max_lines,
 			if (wc == L' ' && (wcp = wcschr(wc_bufp + 1, L' ')) !=
 			    nullptr) {
 				static wchar_t		str[4096] = { L'\0' };
-				static const ptrdiff_t	ARSZ = static_cast
-				    <ptrdiff_t>(ARRAY_SIZE(str));
+				static const auto	ARSZ =
+				    static_cast<ptrdiff_t>(ARRAY_SIZE(str));
 
 				if ((diff = (wcp - wc_bufp)) > ARSZ - 1)
 					diff = ARSZ - 1;
