@@ -1,5 +1,5 @@
 /* String handling functions
-   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -174,6 +174,8 @@ strColor(short int color)
 		return ("Cyan");
 	case COLOR_WHITE:
 		return ("White");
+	default:
+		break;
 	}
 
 	return ("Unknown Color!");
