@@ -106,7 +106,7 @@ HANDLE			g_win_htbl_mtx; // Window hash table mutex
 /* Objects with internal linkage
    ============================= */
 
-static PIRC_WINDOW hash_table[200] = { NULL };
+static PIRC_WINDOW hash_table[800] = { NULL };
 
 /* -------------------------------------------------- */
 
@@ -411,7 +411,7 @@ window_recreate(PIRC_WINDOW window, int rows, int cols)
 	const int HEIGHT = rows - 3;
 
 	if (!is_irc_channel(window->label)) {
-		struct term_window_size newsize = {
+		const struct term_window_size newsize = {
 			.rows = rows - 2,
 			.cols = cols,
 			.start_row = 1,
@@ -765,8 +765,8 @@ spawn_chat_window(CSTRING label, CSTRING title)
 	struct integer_context intctx = {
 		.setting_name = "max_chat_windows",
 		.lo_limit = 10,
-		.hi_limit = 200,
-		.fallback_default = 60,
+		.hi_limit = 800,
+		.fallback_default = 140,
 	};
 
 	if (label == NULL || strings_match(label, ""))
@@ -828,7 +828,7 @@ new_window_title(CSTRING label, CSTRING title)
 void
 window_close_all_priv_conv(void)
 {
-	char	*priv_conv[200] = { NULL };
+	char	*priv_conv[800] = { NULL };
 	size_t	 pc_assigned = 0;
 
 	mutex_lock(&g_win_htbl_mtx);
